<?php
/*
Plugin Name: Task Rocket v3 to v4 Converter
Plugin URI: https://rocketapps.com.au/task_rocket_faq/updating-from-v3-x-to-v4/
Description: Upgrade Task Rocket v3 for v4 Compatibility.
Version: 1.4
Author: Michael Ott
Author Email: hello@michaelott.id.au
Text Domain: taskrocket-v3-to-v4-converter
Domain Path: /languages/
*/

// More info about this tool can be read at
// https://rocketapps.com.au/task_rocket_faq/updating-from-v3-x-to-v4/

// Look for translation file
function load_converter_textdomain() {
    load_plugin_textdomain( 'taskrocket-v3-to-v4-converter', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'load_converter_textdomain' );

// Update checker
require 'plugin-updates/plugin-update-checker.php';
$TRUpdateChecker = PucFactory::buildUpdateChecker(
    'https://taskrocket.info/files/auto-updates/converter/info.json',
    __FILE__,
    'task-rocket-converter'
);

add_action( 'admin_menu', 'trc_add_admin_menu' );
add_action( 'admin_init', 'trc_settings_init' );

function trc_add_admin_menu(  ) { 
	add_menu_page( 'Task Rocket v3 to v4 Converter', 'Task Rocket v3 to v4 Converter', 'manage_options', 'task_rocket_v3_to_v4_converter', 'task_rocket_v3_to_v4_converter_options_page' );
}

function trc_settings_init(  ) { 

	register_setting( 'pluginPage', 'trc_settings' );

	add_settings_section(
		'trc_pluginPage_section', 
		__( ' ', 'taskrocket-v3-to-v4-converter' ), 
		'trc_settings_section_callback', 
		'pluginPage'
	);

	add_settings_field( 
		'trc_checkbox_field_0', 
		__( 'I understand and have taken the necessary precautions', 'taskrocket-v3-to-v4-converter' ), 
		'trc_checkbox_field_0_render', 
		'pluginPage', 
		'trc_pluginPage_section' 
	);


}

function trc_checkbox_field_0_render(  ) { 

	$options = get_option( 'trc_settings' ); ?>
	<input type='checkbox' name='trc_settings[trc_checkbox_field_0]' <?php checked( $options['trc_checkbox_field_0'], 1 ); ?> value='1'>
	<?php
}


function trc_settings_section_callback(  ) { 

	echo __( '<a href="https://taskrocket.info/the-task-rocket-3-x-to-4-0-update-tool?type=faq" target="_blank">Read more</a> about the technical side of what this tool does and why it is required for version 4.0.', 'taskrocket-v3-to-v4-converter' );

}


function task_rocket_v3_to_v4_converter_options_page(  ) { ?>
	<form method='post' class='tr-converter-action'>
		
		<h1><?php _e( "Task Rocket v3 to v4 Converter", "taskrocket-v3-to-v4-converter" ); ?></h1>    
        
        <?php if (isset($_POST['tr-conversion'])) {
			
			
			// Update published posts to use new method of indentifying task statuses
            function wp_update_publish_posts_status($tr_publish_params = null) {
            $tr_publish_args = array(
                'nopaging'     => true, 				        // Loop through all posts
                'post_status'  => array('publish'),             // Target published posts
                'post_type'    => array('post', 'task_groups')  // Target these post types
            );
            
            $tr_publish_query = new WP_Query( $tr_publish_args );
            if ( $tr_publish_query->have_posts() ) {
            
                    while ( $tr_publish_query->have_posts() ) {
                        $tr_publish_query->the_post();
						// Change the status the post to publish
                        $updated = wp_update_post( array('ID' => $tr_publish_query->post->ID, 'post_status' => 'publish' ));
                        //add the post "new_status" meta
                        add_post_meta( $tr_publish_query->post->ID, 'tr_status', 'incomplete' ); 
                    }
                }
            }
            wp_update_publish_posts_status();


            // Update trashed posts to use new method of indentifying task statuses
            function wp_update_trash_posts_status($tr_trash_params = null) {
            $tr_trash_args = array(
                'nopaging'     => true, 		   // Loop through all posts
                'post_status'  => array('trash'),  // Target posts in the trash
                'post_type'    => array('post')    // Target these post types
            );
            
            $tr_trash_query = new WP_Query( $tr_trash_args );
            if ( $tr_trash_query->have_posts() ) {
            
                    while ( $tr_trash_query->have_posts() ) {
                        $tr_trash_query->the_post();
                        // Change the status the post to publish
                        $updated = wp_update_post( array('ID' => $tr_trash_query->post->ID, 'post_status' => 'publish' ));
                        //add the post "new_status" meta
                        add_post_meta( $tr_trash_query->post->ID, 'tr_status', 'complete' ); 
                    }
                }
            }
            wp_update_trash_posts_status();
            
            // Update draft posts to use new method of indentifying task statuses
            function wp_update_draft_posts_status($tr_draft_params = null) {
            $tr_draft_args = array(
                'nopaging'     => true, 		   // Loop through all posts
                'post_status'  => array('draft'),  // Target posts in the draft
                'post_type'    => array('post')    // Target these post types
            );
            
            $tr_draft_query = new WP_Query( $tr_draft_args );
            if ( $tr_draft_query->have_posts() ) {
            
                    while ( $tr_draft_query->have_posts() ) {
                        $tr_draft_query->the_post();
                        // Change the status the post to publish
                        $updated = wp_update_post( array('ID' => $tr_draft_query->post->ID, 'post_status' => 'draft' ));
                        //add the post "new_status" meta
                        add_post_meta( $tr_draft_query->post->ID, 'tr_status', 'incomplete' ); 
                    }
                }
            }
            wp_update_draft_posts_status();
			
        ?>
            <div style="color:#fff; font-size: 14px; display:block; width: 50%;">
                <p style="margin:0; padding:20px; background:#79bb1a; "><strong style="display:block; font-size: 15px;"><?php _e( "All done!", "taskrocket-v3-to-v4-converter" ); ?></strong>
                    <span style="opacity:.8"><?php _e( "Please deactiavte this plugin immediatly and do not run it again.", "taskrocket-v3-to-v4-converter" ); ?></span></p>
            </div>
            
        <?php } else { ?>
            
            <h2 style="color:#EE584F;"><?php _e( "Please read the following information carefully.", "taskrocket-v3-to-v4-converter" ); ?></h2>
            
            <div style="color:#fff; font-size: 14px; display:block; width: 99%; margin:0 0 25px 0; box-sizing:border-box;">
                <p style="margin:0; padding:20px; background:#EE584F; "><strong style="display:block; font-size: 15px;"><?php _e( "What this tool does", "taskrocket-v3-to-v4-converter" ); ?></strong>
                    <span style="opacity:.8">
                        <?php _e( "This tool is used to upgade Task Rocket version 3.x so that it is compatible with version 4.0 and beyond.", "taskrocket-v3-to-v4-converter" ); ?><br />
                        <?php _e( "Specifically it will find all trashed posts (not pages) and change their post_status to 'publish' and also mark them as 'complete'.", "taskrocket-v3-to-v4-converter" ); ?><br />
                        <?php _e( "If you happen to have the Task Groups add-on activated, all task group items will have 'incomplete' status applied to them as well (this is expected). Trashed task group items will be unaffected.", "taskrocket-v3-to-v4-converter" ); ?>
                    </span></p>
                <p style="margin:0; padding:20px; background:#D04C44; "><strong style="display:block; font-size: 15px;"><?php _e( "What to do before using this tool", "taskrocket-v3-to-v4-converter" ); ?></strong>
                    <span style="opacity:.8"><?php _e( "Before you use this tool, <strong>BACKUP YOUR DATABASE and FILES</strong>.", "taskrocket-v3-to-v4-converter" ); ?></span></p>
                <p style="margin:0; padding:20px; background:#EE584F; "><strong style="display:block; font-size: 15px;"><?php _e( "What to do after using this tool", "taskrocket-v3-to-v4-converter" ); ?></strong>
                    <span style="opacity:.8"><?php _e( "Simply deactivate the plugin after you have used it.", "taskrocket-v3-to-v4-converter" ); ?></span></p>
                <p style="margin: 0; padding:20px; background:#D04C44; "><strong style="display:block; font-size: 15px;"><?php _e( "This action can not be undone", "taskrocket-v3-to-v4-converter" ); ?></strong>
                    <span style="opacity:.8"><?php _e( "Once you have used this tool you can not undo the changes. This is why it is important to make a back-up of your database and files.", "taskrocket-v3-to-v4-converter" ); ?></span></p>
            </div>
            
            <?php
    		settings_fields( 'pluginPage' );
    		do_settings_sections( 'pluginPage' );
    		//submit_button();
    		?>
        <?php } ?>
        
        
		<input type="submit" name="tr-conversion" id="tr-conversion" value="<?php _e( "Perform Conversion", "taskrocket-v3-to-v4-converter" ); ?>" class="tr-button" style="border:none; cursor: pointer; display:none;" />
        
        <script>
        $(".tr-converter-action input").click(function () {
            if (this.checked) {
                $(".tr-button").fadeIn();
            } else {
                $(".tr-button").fadeOut();
            }
        });
        </script>
        
	</form>
	<?php
}